<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Arqiver::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="160"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
</context>
<context>
    <name>Arqiver::Backend</name>
    <message>
        <location filename="../../backends.cpp" line="840"/>
        <source>This file is a link but its target does not exist.</source>
        <translation>Este ficheiro é uma ligação mas o seu destino não existe.</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1261"/>
        <location filename="../../backends.cpp" line="1293"/>
        <location filename="../../backends.cpp" line="1337"/>
        <source>Could not read archive</source>
        <translation>Não foi possível ler o arquivo</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1296"/>
        <location filename="../../backends.cpp" line="1342"/>
        <source>Archive Loaded</source>
        <translation>Arquivo carregado</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1303"/>
        <location filename="../../backends.cpp" line="1390"/>
        <source>Modification Finished</source>
        <translation>Modificação concluída</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1324"/>
        <location filename="../../backends.cpp" line="1359"/>
        <source>Extraction Finished</source>
        <translation>Extração concluída</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1327"/>
        <location filename="../../backends.cpp" line="1378"/>
        <source>Extraction Failed</source>
        <translation>Falha ao extrair</translation>
    </message>
    <message>
        <location filename="../../backends.cpp" line="1475"/>
        <source>%1 is missing from your system.
Please install it for this kind of archive!</source>
        <translation>%1 está em falta no seu sistema.
Instale-o para este tipo de arquivo!</translation>
    </message>
</context>
<context>
    <name>Arqiver::LineEdit</name>
    <message>
        <location filename="../../lineedit.h" line="33"/>
        <source>You could type inside the main view.
Clear text with the Escape key.</source>
        <translation>Pode escrever dentro da vista principal.
Limpar texto com a tecla Esc.</translation>
    </message>
</context>
<context>
    <name>Arqiver::PrefDialog</name>
    <message>
        <location filename="../../pref.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="50"/>
        <source>Start with this size:</source>
        <translation>Iniciar com este tamanho:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="118"/>
        <source>Use system icons where possible</source>
        <translation>Usar ícones do sistema sempre que possível</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="125"/>
        <source>Show prompt on removing items</source>
        <translation>Mostrar aviso ao remover itens</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="132"/>
        <source>If this is unchecked, only the top level directories will be expanded.</source>
        <translation>Se isto não for verificado, apenas os diretórios de nível superior serão expandidos.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="135"/>
        <source>Expand all directories when opening archives</source>
        <translation>Expandir todos os diretórios ao abrir os arquivos</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="147"/>
        <location filename="../../pref.ui" line="160"/>
        <source>Leave empty for the default.

Warning: Arqiver will not work if the
binary does not belong to libarchive.</source>
        <translation>Deixar em branco por padrão.

Atenção: O Arqiver não funcionará se o
binário não pertencer ao libarchive.</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="153"/>
        <source>libarchive binary:</source>
        <translation>binário libarchive:</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="38"/>
        <source>Remember window &amp;size on closing</source>
        <translation>Lembrar do ta&amp;manho da janela ao fechar</translation>
    </message>
    <message>
        <location filename="../../pref.ui" line="93"/>
        <source>Size of view icons:</source>
        <translation>Tamanho dos ícones de visualização:</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="62"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="184"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>É necessário reiniciar a aplicação para que as alterações entrem em vigor.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="241"/>
        <source>Select libarchive binary</source>
        <translation>Selecionar binário libarchive</translation>
    </message>
</context>
<context>
    <name>Arqiver::mainWin</name>
    <message>
        <location filename="../../mainWin.ui" line="53"/>
        <source>Archive:</source>
        <translation>Arquivo:</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="106"/>
        <source>Filter Files...</source>
        <translation>Filtrar ficheiros...</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="140"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="155"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="166"/>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="204"/>
        <source>&amp;Open Archive</source>
        <translation>A&amp;brir arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="207"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="212"/>
        <source>&amp;New Archive</source>
        <translation>&amp;Novo arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="215"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="220"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="223"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="228"/>
        <source>Add File(s)</source>
        <translation>Adicionar ficheiro(s)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="233"/>
        <source>Remove File(s)</source>
        <translation>Remover ficheiro(s)</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="238"/>
        <source>Extract All</source>
        <translation>Extrair tudo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="241"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="246"/>
        <source>Add Directory</source>
        <translation>Adicionar diretório</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="251"/>
        <source>Extract Selection</source>
        <translation>Extrair seleção</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="256"/>
        <source>Set Password</source>
        <translation>Definir palavra-passe</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="261"/>
        <source>E&amp;xpand</source>
        <translation>E&amp;xpandir</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="264"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="269"/>
        <source>Collap&amp;se</source>
        <translation>Re&amp;colher</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="272"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="277"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="282"/>
        <source>&amp;Copy Current Path</source>
        <translation>&amp;Copiar caminho atual</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="287"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferências</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="292"/>
        <source>Stop &amp;Process</source>
        <translation>Interromper &amp;processo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="295"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="305"/>
        <source>Update Archive</source>
        <translation>Atualizar arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="147"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="252"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>MimeType</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="323"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="553"/>
        <location filename="../../mainWin.cpp" line="838"/>
        <location filename="../../mainWin.cpp" line="882"/>
        <source>Opening Archive...</source>
        <translation>A abrir arquivo...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="767"/>
        <source>Create Archive</source>
        <translation>Criar Arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="464"/>
        <location filename="../../mainWin.cpp" line="793"/>
        <location filename="../../mainWin.cpp" line="992"/>
        <location filename="../../mainWin.cpp" line="1300"/>
        <source>Question</source>
        <translation>Questão</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="794"/>
        <source>The following archive already exists:</source>
        <translation>O seguinte arquivo já existe:</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="796"/>
        <source>Do you want to replace it?
</source>
        <translation>Deseja substituí-lo?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="830"/>
        <source>Open Archive</source>
        <translation>Abrir Arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="897"/>
        <location filename="../../mainWin.cpp" line="904"/>
        <location filename="../../mainWin.cpp" line="941"/>
        <source>Add to Archive</source>
        <translation>Adicionar ao Arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="936"/>
        <location filename="../../mainWin.cpp" line="967"/>
        <location filename="../../mainWin.cpp" line="1252"/>
        <location filename="../../mainWin.cpp" line="1258"/>
        <source>Adding Items...</source>
        <translation>A adicionar itens...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="993"/>
        <source>Do you want to remove the selected item(s)?
</source>
        <translation>Deseja remover o(s) item(ns) selecionado(s)?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1012"/>
        <source>Removing Items...</source>
        <translation>A remover itens...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1215"/>
        <location filename="../../mainWin.cpp" line="1230"/>
        <location filename="../../mainWin.cpp" line="1315"/>
        <location filename="../../mainWin.cpp" line="1329"/>
        <source>Extracting...</source>
        <translation>A extrair...</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1056"/>
        <source>Copy Archive Path</source>
        <translation>Copiar local do arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="465"/>
        <source>Some files have been modified.</source>
        <translation>Alguns ficheiros foram modificados.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="466"/>
        <source>Do you want to ignore the changes?
</source>
        <translation>Quer ignorar as alterações?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="627"/>
        <source>All Types</source>
        <translation>Todos os tipos</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="637"/>
        <location filename="../../mainWin.cpp" line="661"/>
        <source>Uncompressed Archive</source>
        <translation>Arquivo não comprimido</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="638"/>
        <location filename="../../mainWin.cpp" line="662"/>
        <source>GZip Compressed Archive</source>
        <translation>Arquivo comprimido GZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="639"/>
        <location filename="../../mainWin.cpp" line="663"/>
        <location filename="../../mainWin.cpp" line="664"/>
        <source>BZip Compressed Archive</source>
        <translation>Arquivo comprimido BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="640"/>
        <location filename="../../mainWin.cpp" line="665"/>
        <source>BZip2 Compressed Archive</source>
        <translation>Arquivo comprimido BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="641"/>
        <location filename="../../mainWin.cpp" line="673"/>
        <source>LMZA Compressed Archive</source>
        <translation>Arquivo comprimido LMZA</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="642"/>
        <location filename="../../mainWin.cpp" line="670"/>
        <source>XZ Compressed Archive</source>
        <translation>Arquivo comprimido XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="643"/>
        <location filename="../../mainWin.cpp" line="674"/>
        <source>Zstandard Compressed Archive</source>
        <translation>Arquivo comprimido Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="644"/>
        <location filename="../../mainWin.cpp" line="676"/>
        <source>CPIO Archive</source>
        <translation>Arquivo CPIO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="646"/>
        <location filename="../../mainWin.cpp" line="678"/>
        <source>AR Archive</source>
        <translation>Arquivo AR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="648"/>
        <location filename="../../mainWin.cpp" line="680"/>
        <source>Zip Archive</source>
        <translation>Arquivo Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="649"/>
        <location filename="../../mainWin.cpp" line="682"/>
        <source>Gzip Archive</source>
        <translation>Arquivo Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="650"/>
        <location filename="../../mainWin.cpp" line="681"/>
        <source>7-Zip Archive</source>
        <translation>Arquivo 7-Zip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="666"/>
        <location filename="../../mainWin.cpp" line="667"/>
        <source>READ-ONLY: BZip Archive</source>
        <translation>APENAS-LEITURA: Arquivo BZip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="668"/>
        <source>READ-ONLY: BZip2 Archive</source>
        <translation>APENAS-LEITURA: Arquivo BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="669"/>
        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
        <translation>APENAS-LEITURA: Documento PDF comprimido BZip2</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="671"/>
        <source>READ-ONLY: XZ archive</source>
        <translation>APENAS-LEITURA: Arquivo XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="672"/>
        <source>READ-ONLY: XZ Compressed PDF Document</source>
        <translation>APENAS-LEITURA: Documento PDF comprimido XZ</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="675"/>
        <source>READ-ONLY: Zstandard archive</source>
        <translation>APENAS-LEITURA: Arquivo Zstandard</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="683"/>
        <source>Gzip Compressed PDF Document</source>
        <translation>Documento PDF comprimido Gzip</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="684"/>
        <source>READ-ONLY: Compressed SVG Image</source>
        <translation>APENAS-LEITURA: Imagem SVG comprimida</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="685"/>
        <location filename="../../mainWin.cpp" line="686"/>
        <location filename="../../mainWin.cpp" line="687"/>
        <location filename="../../mainWin.cpp" line="688"/>
        <source>READ-ONLY: ISO Image</source>
        <translation>APENAS-LEITURA: Imagem ISO</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="689"/>
        <source>READ-ONLY: XAR Archive</source>
        <translation>APENAS-LEITURA: Arquivo XAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="690"/>
        <source>READ-ONLY: Java Archive</source>
        <translation>APENAS-LEITURA: Arquivo Java</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="691"/>
        <source>READ-ONLY: Debian Package</source>
        <translation>APENAS-LEITURA: Pacote Debian</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="692"/>
        <location filename="../../mainWin.cpp" line="693"/>
        <source>READ-ONLY: RedHat Package</source>
        <translation>APENAS-LEITURA: Pacote RedHat</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="694"/>
        <location filename="../../mainWin.cpp" line="695"/>
        <location filename="../../mainWin.cpp" line="696"/>
        <source>READ-ONLY: MS Windows Executable</source>
        <translation>APENAS-LEITURA: Executável MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="697"/>
        <source>READ-ONLY: MS Windows Installer Package</source>
        <translation>APENAS-LEITURA: Pacote Instalador MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="698"/>
        <source>READ-ONLY: MS Windows Cabinet Archive</source>
        <translation>APENAS-LEITURA: Arquivo Cabinet MS Windows</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="700"/>
        <source>READ-ONLY: Android Package</source>
        <translation>APENAS-LEITURA: Pacote Android</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="701"/>
        <source>READ-ONLY: RAR Archive</source>
        <translation>APENAS-LEITURA: Arquivo RAR</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="702"/>
        <source>READ-ONLY: AppImage application bundle</source>
        <translation>APENAS-LEITURA: Pacote de aplicação AppImage</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="703"/>
        <source>READ-ONLY: VirtualBox Extension Pack</source>
        <translation>APENAS-LEITURA: VirtualBox Extension Pack</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="712"/>
        <source>All Known Types</source>
        <translation>Todos os tipos conhecidos</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="717"/>
        <source>Show All Files</source>
        <translation>Mostrar todos os ficheiros</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1066"/>
        <source>Open Containing Folder</source>
        <translation>Abrir pasta de conteúdo</translation>
    </message>
    <message>
        <location filename="../../mainWin.ui" line="300"/>
        <source>View Current Item</source>
        <translation>Ver item atual</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1111"/>
        <location filename="../../mainWin.cpp" line="1119"/>
        <source>Enter Password</source>
        <translation>Introduza a palavra-passe</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1127"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1132"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1136"/>
        <source>Encrypt the file list</source>
        <translation>Encriptar a lista de ficheiros</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1137"/>
        <source>This will take effect after files/folders are added.</source>
        <translation>Isto entrará em vigor depois que os ficheiros/pastas forem adicionados.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1208"/>
        <location filename="../../mainWin.cpp" line="1284"/>
        <source>Extract Into Directory</source>
        <translation>Extrair no Diretório</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1301"/>
        <source>Some files will be overwritten.
Do you want to continue?
</source>
        <translation>Alguns ficheiros serão substituídos.
Deseja continuar?
</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1427"/>
        <source>Link To: %1</source>
        <translation>Ligação para: %1</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1694"/>
        <source>Could not read archive</source>
        <translation>Não foi possível ler o arquivo</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1765"/>
        <source>A simple Qt archive manager</source>
        <translation>Um simples gestor de arquivos Qt</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1766"/>
        <source>based on libarchive, gzip and 7z</source>
        <translation>baseado em libarchive, gzip e 7z</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1767"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1768"/>
        <source>aka.</source>
        <translation>aka.</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <location filename="../../mainWin.cpp" line="1770"/>
        <source>About Arqiver</source>
        <translation>Acerca do Arqiver</translation>
    </message>
    <message>
        <location filename="../../mainWin.cpp" line="1769"/>
        <source>Translators</source>
        <translation>Tradutores</translation>
    </message>
</context>
</TS>
